@@ -17,7 +17,7 @@ use crate::{
 	vec::BitVec,
 };
 
-#[cfg(all(feature = "alloc", not(feature = "std")))]
+#[cfg(feature = "alloc")]
 use alloc::{
 	borrow::{
 		Borrow,
@@ -95,16 +95,6 @@ use core::{
 	},
 };
 
-#[cfg(feature = "std")]
-use std::{
-	borrow::{
-		Borrow,
-		BorrowMut,
-	},
-	boxed::Box,
-	vec::Vec,
-};
-
 /** A pointer type for owned bit sequences.
 
 This type is essentially a `&BitSlice` that owns its own memory. It can change
